@@ -11,7 +11,7 @@ class Documentations(View):
 		# the chapter title.
 		title="Chapter Title",
 		# the chapter's sections.
-		sections={},
+		sections=[],
 		# whether the chapter is folded in the leftbar or not.
 		folded=True,
 	):
@@ -23,13 +23,22 @@ class Documentations(View):
 			"element_id":self.__generate_element_id__(),
 		}
 	def section(self,
+		# the title (str, list) (required).
 		title="Section Title",
+		# the description (str, list) (required).
 		description=None,
-		attributes={},
-		parameters={},
-		code_areas={},
+		# the attributes (list) (required).
+		attributes=[],
+		# the parameters (list) (required).
+		parameters=[],
+		# the code areas (list) (required).
+		code_areas=[],
+		# system variables.
+		# the section type (str) (required).
+		type="section",
 	):
-
+		if isinstance(description, (list, Array)):
+			description = Array(description).string(joiner="\n")
 		description = self.__color_description__(description)
 		return {
 			"title":title,
@@ -42,7 +51,28 @@ class Documentations(View):
 			"code_areas":self.__assign_element_ids__(code_areas, key="element_id"),
 			"code_areas_count":len(code_areas),
 			"element_id":self.__generate_element_id__(),
+			"type":type,
 		}
+	def subsection(self,
+		# the title (str, list) (required).
+		title="Sub Section Title",
+		# the description (str, list) (required).
+		description=None,
+		# the attributes (list) (required).
+		attributes=[],
+		# the parameters (list) (required).
+		parameters=[],
+		# the code areas (list) (required).
+		code_areas=[],
+	):
+		return self.section(
+			title=title,
+			description=description,
+			attributes=attributes,
+			parameters=parameters,
+			code_areas=code_areas,
+			type="subsection",
+		)
 	def parameter(self,
 		# the parameters id.
 		id="my_variable",
@@ -55,12 +85,15 @@ class Documentations(View):
 		# whether the parameter is folded by default or not.
 		folded=False,
 	):
+		if isinstance(description, (list, Array)):
+			description = Array(description).string(joiner="\n")
 		return self.__parameter_attribute__(
 			id=id,
 			format=format,
 			description=self.__color_description__(description),
 			required=required,
-			folded=folded,)
+			folded=folded,
+			type="parameter",)
 	def attribute(self,
 		# the attributes id.
 		id="my_variable",
@@ -71,11 +104,14 @@ class Documentations(View):
 		# whether the attribute is folded by default or not.
 		folded=False,
 	):
+		if isinstance(description, (list, Array)):
+			description = Array(description).string(joiner="\n")
 		return self.__parameter_attribute__(
 			id=id,
 			format=format,
 			description=self.__color_description__(description),
-			folded=folded,)
+			folded=folded,
+			type="attribute",)
 	def code_area(self,
 		# the header title.
 		title="my_variable",
@@ -85,7 +121,7 @@ class Documentations(View):
 		content={
 			"json":{},
 			"python":"",
-			# use your own. Unknown types are just non colored strings.
+			# Unknown types are just non colored strings.
 		},
 		# the content css style with python_like or jsLike keys.
 		styles={
@@ -529,8 +565,22 @@ class Documentations(View):
 											break
 									if nointeger in [True, None]: break
 								"""
-								if last[str(len(i)+1)] not in [f" {int_chars}",f"\n{int_chars}",f"\r{int_chars}",f"({int_chars}",f"={int_chars}",f"+{int_chars}",f"-{int_chars}","{"+f"{int_chars}"]:
-								#if lastchar not in [" ","\n","\r","(","=","+","-","{"]:
+								#print(i)
+								no_integer = False
+								for i in [
+									f" {int_chars}",
+									f"\n{int_chars}",
+									f"\r{int_chars}",
+									f"({int_chars}",
+									f"={int_chars}",
+									f"+{int_chars}",
+									f"-{int_chars}",
+									"{"+f"{int_chars}",
+								]:
+
+									if last[str(len(i)+1)] in i:
+										no_integer = True
+								if no_integer:
 									int_chars = ""
 								else:
 									words.append(self.__create_word__(word=_chars_[:-len(int_chars)], joiner="", language=language))
@@ -742,6 +792,8 @@ class Documentations(View):
 			"default":default,
 			"element_id":self.__generate_element_id__(),
 		}
+		#
+
 	# system functions.
 	def __parameter_attribute__(self,
 		id="my_variable",
@@ -749,6 +801,7 @@ class Documentations(View):
 		description=None,
 		required=False,
 		folded=None,
+		type=None,
 	):
 		if isinstance(format, str):
 			format = [format]
@@ -762,9 +815,11 @@ class Documentations(View):
 			"folded":folded,
 			"required":required,
 			"element_id":self.__generate_element_id__(),
+			"type":type,
 		}
 	def __generate_element_id__(self, joiner=""):
 		return joiner+String("").generate(length=32, digits=True, capitalize=True)
+		#
 	def __create_word__(self, color=None, italic=False, type=None, word="", linecount=None, joiner="", language=None, styles={}):
 		colors = {
 			"red":"#FF0071",
@@ -793,6 +848,8 @@ class Documentations(View):
 				if " " in tag: tag = tag.replace(" ", "")
 				else: break
 			return tag
+		if isinstance(description, (list, Array)):
+			description = Array(description).string(joiner="\n")
 		words, c, open, closing, chars, max = [], 0, False, False, "", len(description)
 		while c < max:
 			add_char = True
@@ -867,6 +924,9 @@ class Documentations(View):
 			variable = dictionary
 		else: raise ValueError(f"Unknown variable format: {variable}")
 		return variable
+		#
+
+	#
 
 # the documentation view.
 class DocumentationView(View):
@@ -882,8 +942,6 @@ class DocumentationView(View):
 		html=None,
 		# enable if this view is the [/] landing page.
 		landing_page=False,
-		# the template data (required).
-		template_data={},
 		# the default chapter library.
 		chapters=None,
 		# insert specific colors (insert mode).
@@ -898,7 +956,7 @@ class DocumentationView(View):
 			url=url,
 			html=html,
 			landing_page=landing_page,
-			template_data=template_data,
+			website=website,
 			# the view type.
 			type="DocumentationView",)
 		self.website = website
@@ -953,21 +1011,14 @@ class DocumentationView(View):
 			# custom colors.
 			# ...
 		}
-		for key, value in colors.items():self.colors[key] = value
-		self.template_data["COLORS"] = self.colors
-		try:
-			self.template_data["CHAPTERS"] = {}
-		except KeyError:
-			self.template_data["CHAPTERS"] = {}
-		self.template_data["leftbar_width"] = "250px"
+		for key, value in colors.items(): self.colors[key] = value
+		self.website.template_data = self.website.template({
+			"COLORS":self.colors,
+			"LEFTBAR_WIDTH":"250px",
+		})
 
-		# arguments.
-		if chapters != None:
-			while True:
-				if len(chapters) > 0 and chapters[0] == "/": chapters = chapters[1:]
-				elif len(chapters) > 0 and chapters[len(chapters)-1] == "/": chapters = chapters[:-1]
-				else: break
-			self.include_chapters(chapters)
+		# chapters.
+		self.include_chapters(chapters)
 
 		#
 	def view(self, request):
@@ -976,33 +1027,66 @@ class DocumentationView(View):
 		if response.success:
 			response = self.website.users.get_api_key(email=response.email)
 			if response.success: api_key = response.api_key
-		template_data = dict(self.template_data)
-		template_data["api_key"] = api_key
-		template_data["URL"] = self.url
-		template_data["CHAPTERS"] = self.chapters
 		if self.website.maintenance: return self.maintenance(request)
-		return render(request, f"{ALIAS}/classes/views/html/documentation_view.html", template_data)
-	def include_chapters(self, chapters_library):
-		if not Files.exists(chapters_library):
-			raise ValueError(f"Specified DocumentationView chapters library {chapters_library} does not exist.")
-		self.chapters = {}
-		if os.path.isdir(chapters_library):
-			chapters_library += "/"
-			replaced = chapters_library.replace('/','.').replace(".py", "")
-			for path in Files.Directory(chapters_library).paths():
+		return self.render(request=request, html=f"w3bsite/classes/views/html/documentation_view.html", template_data={
+			"API_KEY":api_key,
+			"URL":self.url,
+			"CHAPTERS":self.chapters,
+		})
+	def include_chapters(self, chapters, reset=True):
+		if isinstance(chapters, (str, String, FilePath)):
+			chapters = str(chapters)
+			while True:
+				if len(chapters) > 0 and chapters[0] == "/": chachapterspters = chapters[1:]
+				elif len(chapters) > 0 and chapters[len(chapters)-1] == "/": chapters = chapters[:-1]
+				else: break
+			if not Files.exists(chapters):
+				raise dev0s.exceptions.InvalidUsage(f"Specified DocumentationView chapters library {chapters} does not exist ({self.url}).")
+			if reset: self.chapters = {}
+			if os.path.isdir(chapters):
+				replaced = (gfp.clean(chapters, remove_first_slash=True, remove_last_slash=True)+"/").replace('/','.').replace(".py", "")
+				for path in Files.Directory(chapters).paths():
+					id = self.__generate_element_id__("chapt_")
+					name = FilePath(path).name().replace(".py", "")
+					if ".py" in path:
+						module = importlib.import_module(f"{replaced}{name}")
+					module_chapters = module.chapters
+					if isinstance(module_chapters, (list, Array)): # multiple chapters.
+						return self.include_chapters(module_chapters, reset=False)
+					elif isinstance(module_chapters, (dict, Dictionary)): # single chapter.
+						self.chapters[id] = module_chapters
+					else:
+						raise dev0s.exceptions.InvalidUsage(f"<dev0s.views.docs.DocumentationView.include_chapters> Imported module chapters from [{chapters}] must be a (Dictionary, Array) not [{module_chapters.__class__.__name__}] ({self.url}).")
+			else:
+				replaced = gfp.clean(chapters, remove_first_slash=True, remove_last_slash=True).replace('/','.').replace(".py", "")
+				name = FilePath(chapters).name().replace(".py", "")
+				module = importlib.import_module(f"{replaced}")
 				id = self.__generate_element_id__("chapt_")
-				name = FilePath(path).name().replace(".py", "")
-				if ".py" in path:
-					module = importlib.import_module(f"{replaced}{name}")
-					self.chapters[id] = module.chapter
+				module_chapters = module.chapters
+				if isinstance(module_chapters, (list, Array)): # multiple chapters.
+					return self.include_chapters(module_chapters, reset=False)
+				elif isinstance(module_chapters, (dict, Dictionary)): # single chapter.
+					self.chapters[id] = module_chapters
+				else:
+					raise dev0s.exceptions.InvalidUsage(f"<dev0s.views.docs.DocumentationView.include_chapters> Imported module chapters from [{chapters}] must be a (Dictionary, Array) not [{module_chapters.__class__.__name__}] ({self.url}).")
+		elif isinstance(chapters, (list, Array)):
+			if reset: self.chapters = {}
+			for item in chapters:
+				self.chapters[item["element_id"]] = item
+		elif isinstance(chapters, dict):
+			if reset: 
+				self.chapters = chapters
+			else:
+				self.chapters = Dictionary(self.chapters) + chapters
+		elif isinstance(chapters, Dictionary):
+			if reset: 
+				self.chapters = chapters.dictionary
+			else:
+				self.chapters = Dictionary(self.chapters) + chapters.dictionary
 		else:
-			replaced = chapters_library.replace('/','.').replace(".py", "")
-			name = FilePath(chapters_library).name().replace(".py", "")
-			module = importlib.import_module(f"{replaced}")
-			id = self.__generate_element_id__("chapt_")
-			self.chapters[id] = module.chapter
+			raise dev0s.exceptions.InvalidUsage(f"<dev0s.views.docs.DocumentationView.include_chapters> Parameter [chapters] must be a (String, FilePath, Dictionary, Array) not [{chapters.__class__.__name__}] ({self.url}).")
 	def __generate_element_id__(self, joiner=""):
-		return joiner+String("").generate(length=32, digits=True, capitalize=True)
+		return joiner+String().generate(length=32, digits=True, capitalize=True)
 	
 
 # initialized docs.
